using System;
using System.Windows.Forms;

namespace PCIBird
{
	/// <summary>
	/// Summary description for Board.
	/// </summary>
	public class Board
	{
		public SerialNumberPCBParameter SerialNumberPCB;

		PCIBirdWrapper pciBird;
		public ushort id;

		//overloaded constructors
		public Board()
		{
			//create wrapper library
			pciBird = new PCIBirdWrapper();
			id = 0; //initialize id to 0
			LoadParameters();
		}
		public Board(ushort ID)
		{
			//create wrapper library
			pciBird = new PCIBirdWrapper();
			id = ID;
			LoadParameters();
		}
		public Board(ushort ID, PCIBirdWrapper pciBirdWrapper)
		{
			//create wrapper library
			pciBird = pciBirdWrapper;
			id = ID;
			LoadParameters();
		}


		private void LoadParameters()
		{
			//instantiate parameters
			SerialNumberPCB = new SerialNumberPCBParameter(id,pciBird);
		}

		public BoardConfig GetBoardConfig()
		{
			return pciBird.GetBoardConfig(id);
		}

		public void PrintBoardConfig(RichTextBox rtb)
		{
			BoardConfig bc = GetBoardConfig();

			
			string ConfigStr =	"\n\nBOARD " + id + " CONFIGURATION:\n" +
							"Serial Number:		"	+ bc.serialNumber + "\n" +
							"Type:			"	+ bc.type + "\n" +
							"Revision:			" + bc.revision + "\n" +
							"Number Transmitters:	" + bc.numberTransmitters + "\n" +
							"Number Sensors:		"	+ bc.numberSensors + "\n" +
							"Firmware Number:		"	+ bc.firmwareNumber + "\n" +
							"Firmware Revision:		"	+ bc.firmwareRevision + "\n" +
							"Model:			"	+ bc.modelString;
			
			rtb.AppendText(ConfigStr);
		}

		public void PrintBoardParameters( RichTextBox rtb )
		{
			string paramStr = "\n\nBOARD " + id + " PARAMETERS\n" +
				"Serial Number RX:	" + this.SerialNumberPCB.Get();
		}
/************************ PARAMETER CLASSES ***********************************/
		public class SerialNumberPCBParameter
		{
			PCIBirdWrapper pciBird;
			ushort id;

			public SerialNumberPCBParameter(ushort ID, PCIBirdWrapper pciBirdWrapper)
			{
				id = ID;
				pciBird = pciBirdWrapper;
			}

			public int Get()
			{
				object o = new int(); 
				pciBird.GetBoardParam(id,BOARD_PARAMETER_TYPE.SERIAL_NUMBER_PCB,o,4);
				return Convert.ToInt32(o);
			}
		}
	}
}
